`Problem Set: propositional`

# Dry Thunder

A logic problem by Adam Richard-Bollans

Your problem is to use propositional logic to represent the following example of reasoning, and use the Prover9 theorem prover to prove that the reasoning is valid.

Use the following template file to create your Prover9 encoding of the problem: `dry_thunder.p9`

Marks: There are two marks for each sentence, making a total of 8 marks.

## Problem Statement

A1 | A Dry Thunderstorm is defined by the occurence of lightning without rain.
A2 | There is a dry thunderstorm.
A3 | If there is lightning then it is either raining or its hot.
Goal | It is hot.

### Non-Logical Vocabulary

Propositional Constants: `DryThunder`, `Lightning`, `Raining`, `Hot`